@@ -23,8 +23,14 @@
 namespace ANN
 {
 
-  typedef Array<double> Term; /* training set term */
+  class NAV<double>
+  {
+  public:
+    static double get() { return NAN; }
+  };
 
+  typedef Array<double> Term; /* training set term */
+  
 } // namespace ANN
 
 #endif /* __ANN_TERM_H */
